<?php

/**
 * Redux Framework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 * Redux Framework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with Redux Framework. If not, see <http://www.gnu.org/licenses/>.
 *
 * @package     ReduxFramework
 * @subpackage  Field_Multi_Text
 * @author      Daniel J Griffiths (Ghost1227)
 * @author      Dovy Paukstys
 * @version     3.0.0
 */
// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) {
	exit;
}

// Don't duplicate me!
if ( !class_exists( 'ReduxFramework_multi_builder' ) ) {

	/**
	 * Main ReduxFramework_multi_builder class
	 *
	 * @since       1.0.0
	 */
	class ReduxFramework_multi_builder {

		/**
		 * Field Constructor.
		 * Required - must call the parent constructor, then assign field and value to vars, and obviously call the render field function
		 *
		 * @since       1.0.0
		 * @access      public
		 * @return      void
		 */
		function __construct( $field = array(), $value = '', $parent ) {
			$this->parent = $parent;
			$this->field = $field;
			$this->value = $value;
		}

		/**
		 * Field Render Function.
		 * Takes the vars and outputs the HTML for the field in the settings
		 *
		 * @since       1.0.0
		 * @access      public
		 * @return      void
		 */
		public function render() {
			$this->add_text = ( isset( $this->field['add_text'] ) ) ? $this->field['add_text'] : __( 'Add More', 'unload' );
			$this->show_empty = ( isset( $this->field['show_empty'] ) ) ? $this->field['show_empty'] : true;

			echo '<ul id="' . $this->field['id'] . '-ul" class="redux-multi-builder">';
			$cols = array(
				'col-md-12',
				'col-md-10',
				'col-md-9',
				'col-md-8',
				'col-md-7',
				'col-md-6',
				'col-md-5',
				'col-md-4',
				'col-md-3',
				'col-md-2',
			);
			$x = 0;
			$counter = 1;
			if ( !empty( $this->value ) && count( $this->value ) > 0 ) {

				foreach ( $this->value as $k => $value ) {

					if ( $value != '' ) {
						echo '<li><input type="text" id="' . $this->field['id'] . '-' . $k . '" name="' . $this->field['name'] . $this->field['name_suffix'] . '[' . $k . '][input_field]' . '" value="' . esc_attr( $value['input_field'] ) . '" class="regular-text ' . $this->field['class'] . '" /><select id="' . $this->field['id'] . '-' . $k . '" name="' . $this->field['name'] . $this->field['name_suffix'] . '[' . $k . '][grid_builder]"' . '>';
						foreach ( $cols as $col ) {
							$selected = ($value['grid_builder'] == $col) ? 'selected="selected"' : '';
							echo '<option ' . $selected . ' value="' . $col . '" id="' . $this->field['id'] . '-' . $k . '" class="regular-text ' . $this->field['class'] . '">' . $col . '</option>';
						}
						echo '</select>  <a href="javascript:void(0);" class="deletion redux-multi-builder-remove">' . __( 'Remove', 'unload' ) . '</a></li>';
					}
					$x++;
					$counter = $k + 1;
				}
			} elseif ( $this->show_empty == true ) {
				echo '<li><input type="text" id="' . $this->field['id'] . '" name="' . $this->field['name'] . $this->field['name_suffix'] . '[0][input_field]' . '" value="" class="regular-text ' . $this->field['class'] . '" /><select id="builder" name="' . $this->field['name'] . $this->field['name_suffix'] . '[0][grid_builder]">';
				foreach ( $cols as $col ) {
					echo '<option value="' . $col . '" value="" class="regular-text ' . $this->field['class'] . '">' . $col . '</option>';
				}
				echo '</select> <a href="javascript:void(0);" class="deletion redux-multi-builder-remove">' . __( 'Remove', 'unload' ) . '</a></li>';
			}

			echo '<li style="display:none;"><input type="text" id="' . $this->field['id'] . '" name="" value="" class="regular-text" /><select id="builder"> ';
			foreach ( $cols as $col ) {
				echo '<option id="' . $this->field['id'] . '" value="' . $col . '" class="regular-text">' . $col . '</option>';
			}
			echo '</select><a href="javascript:void(0);" class="deletion redux-multi-builder-remove">' . __( 'Remove', 'unload' ) . '</a></li></ul>';
			echo '<span style="clear:both;display:block;height:0;" /></span>';
			$this->field['add_number'] = ( isset( $this->field['add_number'] ) && is_numeric( $this->field['add_number'] ) ) ? $this->field['add_number'] : 1;
			echo '<a href="javascript:void(0);" class="button button-primary redux-multi-builder-add" data-item_number="' . $counter . '" data-add_number="' . $this->field['add_number'] . '" data-id="' . $this->field['id'] . '-ul" data-first-name="' . $this->field['name'] . $this->field['name_suffix'] . '[counter][input_field]" data-second-name="' . $this->field['name'] . $this->field['name_suffix'] . '[counter][grid_builder]">' . $this->add_text . '</a><br/>';
		}

		/**
		 * Enqueue Function.
		 * If this field requires any scripts, or css define this function and register/enqueue the scripts/css
		 *
		 * @since       1.0.0
		 * @access      public
		 * @return      void
		 */
		public function enqueue() {

			wp_enqueue_script(
					'redux-field-multi-builder-js', ReduxFramework::$_url . 'inc/fields/multi_builder/field_multi_builder' . Redux_Functions::isMin() . '.js', array( 'jquery', 'redux-js' ), time(), true
			);


			wp_enqueue_style(
					'redux-field-multi-builder-css', ReduxFramework::$_url . 'inc/fields/multi_builder/field_multi_builder.css', array(), time(), 'all'
			);
		}

	}

}